@@ -2,12 +2,13 @@ __version__ = "0.1.0"
 
 
 from .custom_scalar import scalar  # noqa
+from .directive import directive  # noqa
 from .enum import enum  # noqa
 from .field import field  # noqa
 from .mutation import mutation, subscription  # noqa
+from .permission import BasePermission  # noqa
 from .scalars import ID  # noqa
 from .schema import Schema  # noqa
-from .type import input, type, interface  # noqa
+from .type import input, interface, type  # noqa
 from .types import *  # noqa
-from .permission import BasePermission  # noqa
-from .directive import directive  # noqa
+from .union import union  # noqa
