@@ -3,7 +3,7 @@ import enum
 import inspect
 import typing
 
-from graphql import GraphQLField, GraphQLInputField
+from graphql import GraphQLArgument, GraphQLField, GraphQLInputField, Undefined
 
 from .constants import IS_STRAWBERRY_FIELD
 from .exceptions import MissingArgumentsAnnotationsError, MissingReturnAnnotationError
@@ -100,7 +100,7 @@ class LazyFieldWrapper:
                 raise PermissionError(message)
 
     @lazy_property
-    def field(self):
+    def graphql_type(self):
         return _get_field(
             self._wrapped_obj,
             is_input=self.is_input,
@@ -203,19 +203,39 @@ def _get_field(
         if key not in ["info", "return"]
     }
 
-    arguments = {
-        to_camel_case(name): get_graphql_type_for_annotation(
-            annotation, name, parameters[name].default != inspect._empty
+    arguments = {}
+    for name, annotation in arguments_annotations.items():
+        default = parameters[name].default
+        arguments[to_camel_case(name)] = GraphQLArgument(
+            get_graphql_type_for_annotation(annotation, name, default is None),
+            default_value=Undefined if default in (inspect._empty, None) else default,
         )
-        for name, annotation in arguments_annotations.items()
-    }
 
     def resolver(source, info, **kwargs):
         if check_permission:
             check_permission(source, info, **kwargs)
 
+        # the following code allows to omit info and root arguments
+        # by inspecting the original resolver arguments,
+        # if it asks for self, the source will be passed as first argument
+        # if it asks for root, the source it will be passed as kwarg
+        # if it asks for info, the info will be passed as kwarg
+
         kwargs = convert_args(kwargs, arguments_annotations)
-        result = wrap(source, info, **kwargs)
+        function_args = get_func_args(wrap)
+
+        args = []
+
+        if "self" in function_args:
+            args.append(source)
+
+        if "root" in function_args:
+            kwargs["root"] = source
+
+        if "info" in function_args:
+            kwargs["info"] = info
+
+        result = wrap(*args, **kwargs)
 
         # graphql-core expects a resolver for an Enum type to return
         # the enum's *value* (not its name or an instance of the enum).
@@ -231,9 +251,9 @@ def _get_field(
 
         if is_subscription:
 
-            def _resolve(event, info):
+            def _resolve(event, info, **kwargs):
                 if check_permission:
-                    check_permission(event, info)
+                    check_permission(event, info, **kwargs)
 
                 return event
 
