@@ -1,3 +1,4 @@
+import copy
 import dataclasses
 from functools import partial
 
@@ -7,12 +8,12 @@ from .constants import IS_STRAWBERRY_FIELD, IS_STRAWBERRY_INPUT, IS_STRAWBERRY_I
 from .field import field, strawberry_field
 from .type_converter import REGISTRY
 from .utils.str_converters import to_camel_case
-from .utils.typing import get_actual_type
+from .utils.typing import get_actual_type, has_type_var, is_type_var
 
 
 def _interface_resolve_type(result, info, return_type):
     """Resolves the correct type for an interface"""
-    return result.__class__.field
+    return result.__class__.graphql_type
 
 
 def _get_resolver(cls, field_name):
@@ -49,7 +50,13 @@ def _process_type(cls, *, is_input=False, is_interface=False, description=None):
         fields = {}
 
         for class_field in class_fields:
-            class_field.type = get_actual_type(class_field.type, types_replacement_map)
+            # we want to make a copy of the original field when dealing
+            # with generic types and also get the actual type for the type var
+            if is_type_var(class_field.type) or has_type_var(class_field.type):
+                class_field = copy.copy(class_field)
+                class_field.type = get_actual_type(
+                    class_field.type, types_replacement_map
+                )
 
             field_name = getattr(class_field, "field_name", None) or to_camel_case(
                 class_field.name
@@ -66,7 +73,10 @@ def _process_type(cls, *, is_input=False, is_interface=False, description=None):
                 is_input=is_input,
                 description=description,
                 permission_classes=permission_classes,
-            ).field
+            ).graphql_type
+            # supply a graphql default_value if the type annotation has a default
+            if class_field.default not in (dataclasses.MISSING, None):
+                fields[field_name].default_value = class_field.default
 
         strawberry_fields = {}
 
@@ -82,7 +92,7 @@ def _process_type(cls, *, is_input=False, is_interface=False, description=None):
         for key, value in strawberry_fields.items():
             name = getattr(value, "field_name", None) or to_camel_case(key)
 
-            fields[name] = value.field
+            fields[name] = value.graphql_type
 
         return fields
 
@@ -108,12 +118,12 @@ def _process_type(cls, *, is_input=False, is_interface=False, description=None):
         TypeClass = GraphQLObjectType
 
         extra_kwargs["interfaces"] = [
-            klass.field
+            klass.graphql_type
             for klass in cls.__bases__
             if hasattr(klass, IS_STRAWBERRY_INTERFACE)
         ]
 
-    wrapped.field = TypeClass(
+    wrapped.graphql_type = TypeClass(
         name,
         lambda types_replacement_map=None: _get_fields(wrapped, types_replacement_map),
         **extra_kwargs
