@@ -3,7 +3,7 @@ import re
 
 # Adapted from this response in Stackoverflow
 # http://stackoverflow.com/a/19053800/1072990
-def to_camel_case(snake_str):
+def to_camel_case(snake_str: str) -> str:
     components = snake_str.split("_")
     # We capitalize the first letter of each component except the first one
     # with the 'capitalize' method and join them together.
@@ -12,10 +12,14 @@ def to_camel_case(snake_str):
 
 # From this response in Stackoverflow
 # http://stackoverflow.com/a/1176023/1072990
-def to_snake_case(name):
+def to_snake_case(name: str) -> str:
     s1 = re.sub(r"(.)([A-Z][a-z]+)", r"\1_\2", name)
     return re.sub(r"([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
 
 
-def to_const(string):
+def to_const(string: str) -> str:
     return re.sub(r"[\W|^]+", "_", string).upper()
+
+
+def capitalize_first(name: str) -> str:
+    return name[0].upper() + name[1:]
